@@ -47,16 +47,30 @@ def getSupportedIface():
 	type = 1
 	i = 0
 	supportedIface.clear()
-	while i < countIface:
-		iface = my_db.getIfaceByType( type )
-		if iface != None:
-			supportedIface[ type ] = iface
-			i += 1
-			if bufOpenSession.has_key( iface ) == False:
-				bufOpenSession[ iface ] = None
-				bufOpenSession[ iface + "_keyread" ] = ifaceExist( iface )
-				bufOpenSession[ iface + "_record" ] = my_db.isAutoRecEnable( iface )
-		type += 1
+	#suppIface = my_db.getBuffIface()
+	listSuppIface = my_db.optGetSupportIface()
+	for dataIface in listSuppIface:
+		iface = dataIface['iface']
+		supportedIface[ dataIface['type'] ] = iface
+		if bufOpenSession.has_key( dataIface['iface'] ) == False:
+			bufOpenSession[ iface ] = None
+			if ifaceExist( iface ) != 0:
+				bufOpenSession[ iface + "_keyread" ] = True
+			else:
+				bufOpenSession[ iface + "_keyread" ] = False
+			bufOpenSession[ iface + "_record" ] = my_db.isAutoRecEnable( dataIface['type'] )
+			readTrafOnIface( iface )
+
+#	while i < countIface:
+#		iface = my_db.getIfaceByType( type )
+#		if iface != None:
+#			supportedIface[ type ] = iface
+#			i += 1
+#			if bufOpenSession.has_key( iface ) == False:
+#				bufOpenSession[ iface ] = None
+#				bufOpenSession[ iface + "_keyread" ] = ifaceExist( iface )
+#				bufOpenSession[ iface + "_record" ] = my_db.isAutoRecEnable( iface )
+#		type += 1
 
 
 #------------------------------------------------------------------------------------------------#
@@ -118,7 +132,6 @@ class QNetManDBusServer(dbus.service.Object):
 	#экспортный метод: eуправляет конфигурацией демона
 	@dbus.service.method("com.qnetman.Daemon", in_signature='', out_signature='')
 	def configUpdate(self):
-		print "QNetManDBusServer::configUpdate(): call"
 		global config_TIMEOUT, supportedIface
 
 		TIMEOUT = my_db.optGetFreqTraffDaemon()
@@ -244,6 +257,7 @@ def readTrafOnIface(iface):
 	except KeyError:
 		keyRecordSession = False
 	
+	#print "readTrafOnIface(%s): bufOpenSession[%s_keyread]=%s bufOpenSession[%s_record]=%s bufOpenSession[%s]=%s"%(iface,iface,keyReadSession,iface,keyRecordSession,iface, timeStartSession)
 	#сессия не стартовала (timeStartSession = None) но есть разрешение на старт keyReadSession = True => стартуем новую сессию
 	if keyReadSession and keyRecordSession and (timeStartSession == None):
 		bufOpenSession[ iface ] = my_db.startSession( type ) #!!!! type
@@ -320,17 +334,17 @@ if __name__ == "__main__":
 		system_bus.add_signal_receiver(addNetIface, "add", "org.kernel.kevent", None, "/org/kernel/class/net/"+iface, path_keyword='iface')
 
 	
-
-	#--- Чтение настроек об автозаписи на сетевых интерфейсах ---#
-	for t_iface in supportedIface.keys():
-		iface = supportedIface[ t_iface ]
-		auto_rec = my_db.isAutoRecEnable( t_iface )
-		bufOpenSession[ iface ] = None
-		bufOpenSession[ iface+"_keyread" ] = False
-		if auto_rec == True:
-			bufOpenSession[ iface+"_record" ] = True   # автозапись разрешена
-		else:
-			bufOpenSession[ iface+"_record" ] = False  # автозапись не разрешена
+#безобразие
+#	#--- Чтение настроек об автозаписи на сетевых интерфейсах ---#
+#	for t_iface in supportedIface.keys():
+#		iface = supportedIface[ t_iface ]
+#		auto_rec = my_db.isAutoRecEnable( t_iface )
+#		bufOpenSession[ iface ] = None
+#		#bufOpenSession[ iface+"_keyread" ] = False
+#		if auto_rec == True:
+#			bufOpenSession[ iface+"_record" ] = True   # автозапись разрешена
+#		else:
+#			bufOpenSession[ iface+"_record" ] = False  # автозапись не разрешена
 
 
 	#--- Готовим объект на шину dbus для взаимодействия с программой QNetworkManager ---#
@@ -358,7 +372,7 @@ if __name__ == "__main__":
 	#--- по выходу из демона останавливаем все запущенные сессии записей ---#
 	for t_iface in supportedIface.keys():
 		iface = supportedIface[ t_iface ]
-		print bufOpenSession
+		#print bufOpenSession
 		if bufOpenSession[ iface ] != None:
 			my_db.stopSession( bufOpenSession[ iface ], t_iface )
 			print "daemonQNetMan: stopSession( %s, %s )"%( bufOpenSession[ iface ], t_iface )
