@@ -102,17 +102,12 @@
 <context>
     <name>DialogMonitorOptions</name>
     <message>
-        <location filename="MonitorOptions.py" line="87"/>
+        <location filename="MonitorOptions.py" line="77"/>
         <source>QNetMan (Monitor options)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MonitorOptions.py" line="88"/>
-        <source>Marker</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="MonitorOptions.py" line="89"/>
+        <location filename="MonitorOptions.py" line="78"/>
         <source>Timestamp (vertcal line), seconds:</source>
         <translation type="unfinished"></translation>
     </message>
@@ -145,7 +140,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogRecordDataExt.py" line="115"/>
+        <location filename="DialogRecordDataExt.py" line="116"/>
         <source>Network interface</source>
         <translation type="unfinished"></translation>
     </message>
@@ -158,7 +153,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogRecordData.py" line="52"/>
+        <location filename="DialogRecordData.py" line="53"/>
         <source>Auto
 record</source>
         <translation type="unfinished"></translation>
@@ -212,6 +207,29 @@ record</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>DialogSessionOptions</name>
+    <message>
+        <location filename="ViewSessionOptions.py" line="75"/>
+        <source>QNetMan (Session options)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="ViewSessionOptions.py" line="76"/>
+        <source>Marker</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="ViewSessionOptions.py" line="77"/>
+        <source>Timestamp (vertcal line), min:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="ViewSessionOptions.py" line="78"/>
+        <source>RX / TX:</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>ListSessions</name>
     <message>
@@ -263,67 +281,67 @@ record</source>
 <context>
     <name>ListSessionsExt</name>
     <message>
-        <location filename="ListSessionsExt.py" line="98"/>
+        <location filename="ListSessionsExt.py" line="107"/>
         <source>Deleting sessions</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="99"/>
+        <location filename="ListSessionsExt.py" line="108"/>
         <source>Delete selected sessions ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="161"/>
+        <location filename="ListSessionsExt.py" line="170"/>
         <source>Session full time:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="239"/>
+        <location filename="ListSessionsExt.py" line="264"/>
         <source>Warning</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="240"/>
+        <location filename="ListSessionsExt.py" line="265"/>
         <source>Session does not contain data</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="286"/>
+        <location filename="ListSessionsExt.py" line="323"/>
         <source>records</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="117"/>
+        <location filename="ListSessionsExt.py" line="126"/>
         <source>Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="118"/>
+        <location filename="ListSessionsExt.py" line="127"/>
         <source>Sorry, an error in the database.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="324"/>
+        <location filename="ListSessionsExt.py" line="361"/>
         <source>Select a session to calculate the traffic</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="329"/>
+        <location filename="ListSessionsExt.py" line="366"/>
         <source>Sessions:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="332"/>
+        <location filename="ListSessionsExt.py" line="369"/>
         <source>Full traffic:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="330"/>
+        <location filename="ListSessionsExt.py" line="367"/>
         <source>RX bytes:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="331"/>
+        <location filename="ListSessionsExt.py" line="368"/>
         <source>TX bytes:</source>
         <translation type="unfinished"></translation>
     </message>
@@ -336,7 +354,7 @@ record</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindow.py" line="77"/>
+        <location filename="MainWindow.py" line="78"/>
         <source>Network
 sessions</source>
         <translation type="unfinished"></translation>
@@ -347,13 +365,13 @@ sessions</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindow.py" line="82"/>
+        <location filename="MainWindow.py" line="83"/>
         <source>Network
 connections</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="232"/>
+        <location filename="ViewSession.py" line="225"/>
         <source>Menu</source>
         <translation type="unfinished"></translation>
     </message>
@@ -548,67 +566,62 @@ connections</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="211"/>
+        <location filename="ViewSession.py" line="204"/>
         <source>QNetMan (Sessions)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="212"/>
+        <location filename="ViewSession.py" line="205"/>
         <source>Session start time:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="213"/>
+        <location filename="ViewSession.py" line="206"/>
         <source>Session end time:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="215"/>
+        <location filename="ViewSession.py" line="208"/>
         <source>2000-01-01 00:00:00</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="225"/>
+        <location filename="ViewSession.py" line="217"/>
         <source>RX:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="219"/>
+        <location filename="ViewSession.py" line="212"/>
         <source>0000.00 MB</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="226"/>
+        <location filename="ViewSession.py" line="218"/>
         <source>TX:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="220"/>
+        <location filename="ViewSession.py" line="213"/>
         <source>Session full time:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="221"/>
+        <location filename="ViewSession.py" line="214"/>
         <source>00 h; 00 m; 00 s</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="222"/>
+        <location filename="ViewSession.py" line="215"/>
         <source>Full session traffic :</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="223"/>
+        <location filename="ViewSession.py" line="216"/>
         <source>000000 MB</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="224"/>
-        <source>Rendering...</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="ViewSession.py" line="233"/>
+        <location filename="ViewSession.py" line="226"/>
         <source>Remove session</source>
         <translation type="unfinished"></translation>
     </message>
@@ -653,7 +666,7 @@ connections</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinAbout.py" line="95"/>
+        <location filename="WinAbout.py" line="99"/>
         <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
 &lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
 p, li { white-space: pre-wrap; }
@@ -697,13 +710,13 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindow.py" line="79"/>
+        <location filename="MainWindow.py" line="80"/>
         <source>Monitor 
 connections</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="231"/>
+        <location filename="ViewSession.py" line="223"/>
         <source>000 kB/s</source>
         <translation type="unfinished"></translation>
     </message>
@@ -712,42 +725,47 @@ connections</source>
         <source>0.4.0</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="ViewSession.py" line="224"/>
+        <source>Please, wait ...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWindowExt</name>
     <message>
-        <location filename="MainWindowExt.py" line="29"/>
+        <location filename="MainWindowExt.py" line="36"/>
         <source>Daemon QNetMan is not running.
 Start daemons now ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindowExt.py" line="30"/>
+        <location filename="MainWindowExt.py" line="37"/>
         <source>Warning</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindowExt.py" line="35"/>
+        <location filename="MainWindowExt.py" line="42"/>
         <source>Information</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindowExt.py" line="36"/>
+        <location filename="MainWindowExt.py" line="43"/>
         <source>Please restart the program now.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindowExt.py" line="39"/>
+        <location filename="MainWindowExt.py" line="46"/>
         <source>Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindowExt.py" line="40"/>
+        <location filename="MainWindowExt.py" line="47"/>
         <source>Failed to start daemon.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindowExt.py" line="43"/>
+        <location filename="MainWindowExt.py" line="50"/>
         <source>Features will be limited.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -755,17 +773,17 @@ Start daemons now ?</source>
 <context>
     <name>OptionsWindowExt</name>
     <message>
-        <location filename="OptionsWindowExt.py" line="296"/>
+        <location filename="OptionsWindowExt.py" line="298"/>
         <source>Warning</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindowExt.py" line="281"/>
+        <location filename="OptionsWindowExt.py" line="283"/>
         <source>Should be left on at least one network interface</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="OptionsWindowExt.py" line="297"/>
+        <location filename="OptionsWindowExt.py" line="299"/>
         <source>Before you disable the network interface, turn off the record on this network interface</source>
         <translation type="unfinished"></translation>
     </message>
@@ -841,22 +859,22 @@ Start daemons now ?</source>
 <context>
     <name>ViewCurrentSessionExt</name>
     <message>
-        <location filename="ViewCurrentSessionExt.py" line="486"/>
+        <location filename="ViewCurrentSessionExt.py" line="501"/>
         <source>Refresh interval:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSessionExt.py" line="487"/>
+        <location filename="ViewCurrentSessionExt.py" line="502"/>
         <source>sec</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSessionExt.py" line="617"/>
+        <location filename="ViewCurrentSessionExt.py" line="631"/>
         <source>Selected network interface:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSessionExt.py" line="660"/>
+        <location filename="ViewCurrentSessionExt.py" line="674"/>
         <source>Recording...</source>
         <translation type="unfinished"></translation>
     </message>
@@ -864,17 +882,17 @@ Start daemons now ?</source>
 <context>
     <name>ViewSessionExt</name>
     <message>
-        <location filename="ViewSessionExt.py" line="148"/>
+        <location filename="ViewSessionExt.py" line="206"/>
         <source>h</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSessionExt.py" line="149"/>
+        <location filename="ViewSessionExt.py" line="207"/>
         <source>m</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSessionExt.py" line="150"/>
+        <location filename="ViewSessionExt.py" line="208"/>
         <source>s</source>
         <translation type="unfinished"></translation>
     </message>
@@ -882,32 +900,32 @@ Start daemons now ?</source>
 <context>
     <name>WinAboutExt</name>
     <message>
-        <location filename="WinAboutExt.py" line="131"/>
+        <location filename="WinAboutExt.py" line="132"/>
         <source>Thanks:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinAboutExt.py" line="144"/>
+        <location filename="WinAboutExt.py" line="145"/>
         <source>Licence:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinAboutExt.py" line="145"/>
+        <location filename="WinAboutExt.py" line="146"/>
         <source>GPL v2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinAboutExt.py" line="133"/>
+        <location filename="WinAboutExt.py" line="134"/>
         <source>Used icon set &quot;Crystal-clear&quot; by Everaldo Coelho</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinAboutExt.py" line="122"/>
+        <location filename="WinAboutExt.py" line="123"/>
         <source>Qt-based network manager which allows to monitor your network traffic. It is possible to record network sessions information for different connections and provide the information in graphical view.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinAboutExt.py" line="132"/>
+        <location filename="WinAboutExt.py" line="133"/>
         <source>Vladimir Sinichkin - for translation</source>
         <translation type="unfinished"></translation>
     </message>
@@ -925,7 +943,7 @@ Start daemons now ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStat.py" line="122"/>
+        <location filename="WinNetStat.py" line="123"/>
         <source>Auto
 refresh</source>
         <translation type="unfinished"></translation>
@@ -964,17 +982,17 @@ refresh</source>
 <context>
     <name>WinNetStatExt</name>
     <message>
-        <location filename="WinNetStatExt.py" line="228"/>
+        <location filename="WinNetStatExt.py" line="229"/>
         <source>Refresh interval:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatExt.py" line="229"/>
+        <location filename="WinNetStatExt.py" line="230"/>
         <source>sec</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatExt.py" line="239"/>
+        <location filename="WinNetStatExt.py" line="240"/>
         <source>Please, wait...</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1012,7 +1030,7 @@ refresh</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogNetworkIface.py" line="63"/>
+        <location filename="DialogNetworkIface.py" line="64"/>
         <source>Select the network interface
  for monitoring</source>
         <translation type="unfinished"></translation>
