@@ -15,23 +15,26 @@ import myconfig
 from MyNotify import MyNotify
 
 class ListSessionsExt( QtGui.QMainWindow ):
-	def __init__(self, parent = None):
+	def __init__(self, parent, mydb, qset):
 		QtGui.QMainWindow.__init__( self, parent )
 		self.parent = parent
 		
 		try:
 			self.setAttribute( QtCore.Qt.WA_Maemo5StackedWindow )
+			self.setAttribute( QtCore.Qt.WA_Maemo5ShowProgressIndicator )
 		except Exception, e:
 			pass
 			#print "ListSessionsExt::__init__(): Exception setAttribute(): ",e
 
 		self.ui = Ui_ListSessions()
 		self.ui.setupUi( self )
-		self.actionForm()
 		
-		self.db = MyDB( myconfig.file_db )
+		#self.db = MyDB( myconfig.file_db )
+		self.db = mydb
 		
 		self.noti = MyNotify()
+
+		self.qset = qset
 		
 		#хранит текущий выбраный пункт списка - сессию
 		self.currentSelectedItem = None
@@ -40,6 +43,10 @@ class ListSessionsExt( QtGui.QMainWindow ):
 		self.startTime_filter = None
 		self.endTime_filter = None
 		self.sessionType_filter = 0
+		self.status_filter = qset.filterGetStatus()
+		self.showWinFilter = True
+		
+		self.actionForm()
 
 	def actionForm(self):
 		self.ui.listWidgetSessions.itemClicked.connect( self.clickedItem )
@@ -56,6 +63,7 @@ class ListSessionsExt( QtGui.QMainWindow ):
 		
 		plugin = MyItemDelegate( self, 1 )
 		self.ui.listWidgetSessions.setItemDelegate( plugin )
+		
 
 #	def keyReleaseEvent(self, ev):
 #		if ev.key() == 65:
@@ -168,6 +176,17 @@ class ListSessionsExt( QtGui.QMainWindow ):
 		item.setData( QtCore.Qt.UserRole+3, 0 )
 
 		self.ui.listWidgetSessions.addItem( item )
+		return item
+
+	def activateFilter(self):
+		#если фильтр вкл, вдавим кнопку фильтра :)
+		if self.status_filter != 0:
+			self.showWinFilter = False
+			self.ui.pBFilter.setChecked( True )
+		else:
+			self.ui.pBFilter.setChecked( False )
+			#self.initItemsSession()
+			self.initItemsSession( self.startTime_filter, self.endTime_filter, self.sessionType_filter )
 
 
 	def initItemsSession(self, startTime = None, endTime = None, filterType = 0):
@@ -187,6 +206,7 @@ class ListSessionsExt( QtGui.QMainWindow ):
 		#создаем пункты списка - сессии
 		j = 0
 		len_buff = len( self.listSessionItems )
+		last_item = None
 		while j < len_buff:
 			strFormatDateTime = self.db.optGetDateTimeFormat()
 
@@ -214,8 +234,12 @@ class ListSessionsExt( QtGui.QMainWindow ):
 				tx = StatistData.strHumanBytes( tx )
 				strTraff = "rx/tx: %s/%s"%( rx, tx )
 
-			self.addItemSession( str, typeSess, longTimeSess, strTraff )
+			last_item = self.addItemSession( str, typeSess, longTimeSess, strTraff )
 			j += 1
+
+		#спускаемся к последнему пункту
+		if len_buff > 0:
+			self.ui.listWidgetSessions.setCurrentItem( last_item )
 		
 		if len(self.ui.listWidgetSessions.selectedItems()) == 0:
 			self.ui.pBViewItem.setEnabled( False )
@@ -249,17 +273,28 @@ class ListSessionsExt( QtGui.QMainWindow ):
 			buf[0]["type_session"] = el0["type_session"]
 			buf[1] = el0
 			
-		self.mwViewSession = ViewSessionExt( self, self.currentSelectedItem.text(), buf )
+		self.mwViewSession = ViewSessionExt( self, self.db, self.qset, self.currentSelectedItem.text(), buf )
 		self.mwViewSession.show()
 		self.mwViewSession.setTimeSession( allSeconds, h, m, s )
 		self.mwViewSession.showData()
 
 	def winFilter(self, state):
 		if state:
-			self.mwFilterOptions = WindowFilterOptionsExt( self, self.ui )
-			self.mwFilterOptions.show()
+			self.mwFilterOptions = WindowFilterOptionsExt( self, self.ui, self.qset )
+			if self.showWinFilter:
+				self.mwFilterOptions.show()
+			else:
+				#смотрим данные о фильтре в настройках
+				startTime_f = self.qset.filterGetStartTime()
+				stopTime_f = self.qset.filterGetStopTime()
+				iface_f = self.qset.filterGetIfaceType()
+				#TODO:при релизе убрать эти две строки
+				status_f = self.qset.filterGetStatus()
+				self.initItemsSession(startTime_f, stopTime_f, iface_f)
 		else:
 			self.initItemsSession()
+			self.qset.filterSetStatus(0)
+		self.showWinFilter = True
 
 	#--- диалог со статистикой БД ---
 	def DlgDBStatistics(self):
