@@ -15,7 +15,7 @@ from collections import deque
 
 import dbus
 
-import QNMSettings
+#import QNMSettings
 
 from gettraff import GetTraff
 from mydb import MyDB
@@ -38,19 +38,20 @@ class MyGraphicsScene( QtGui.QGraphicsScene ):
 
 
 class ViewCurrentSessionExt( QtGui.QMainWindow ):
-	def __init__(self, parent, mydbus, iface='gprs0'):
+	def __init__(self, parent, mydb, mydbus, qset, iface='gprs0'):
 		QtGui.QMainWindow.__init__(self, parent)
 
 		self.mydbus = mydbus
-		self.db = MyDB( myconfig.file_db )
+		self.db = mydb
 
 		try:
 			self.setAttribute( QtCore.Qt.WA_Maemo5StackedWindow )
+			self.setAttribute( QtCore.Qt.WA_Maemo5ShowProgressIndicator )
 		except Exception, e:
 			pass
 			#print "ViewCurrentSessionExt::__init__(): Exception setAttribute(): ",e
 
-		self.qset = QNMSettings.QNMSettings( myconfig.file_setting, self )
+		self.qset = qset
 
 		self.frm = ViewCurrentSession.Ui_ViewCurrentSession()
 		self.frm.setupUi( self )
@@ -633,7 +634,7 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 	#-----------------#
 	def dlgRecordData(self):
 		self.dlgRec = QtGui.QDialog()
-		self.ui_dlgRec = DialogRecordDataExt.DialogRecordManagerExt( self.dlgRec, self.mydbus )
+		self.ui_dlgRec = DialogRecordDataExt.DialogRecordManagerExt( self.dlgRec, self.db, self.mydbus )
 		self.ui_dlgRec.stateRecordChange.connect( self.stateRecordChangeHere )
 		self.dlgRec.show()
 		self.dlgRec.exec_()
