@@ -9,11 +9,14 @@ import StatistData
 from collections import deque
 from sys import path
 
-import myconfig
-from mydb import MyDB
+#import myconfig
+#from mydb import MyDB
+
+from MyGraphicsScene import MyGraphicsScene
+import ViewSessionOptions
 
 class ViewSessionExt( QtGui.QMainWindow ):
-	def __init__(self, parent, title, buffSessionTraff ):
+	def __init__(self, parent, db, qset, title, buffSessionTraff ):
 		QtGui.QMainWindow.__init__(self, parent)
 				
 		#массив всех данных трафика за сессию
@@ -30,7 +33,6 @@ class ViewSessionExt( QtGui.QMainWindow ):
 
 		self.ui = ViewSession.Ui_MainWindow()
 		self.ui.setupUi( self )
-		self.actionForm()
 
 		#self.setWindowTitle( title )
 
@@ -47,21 +49,43 @@ class ViewSessionExt( QtGui.QMainWindow ):
 		self.Lx = self.lengthX-self.shiftX
 
 		#self.X=0
-		self.scene = QtGui.QGraphicsScene()
+		##self.scene = QtGui.QGraphicsScene()
+		##XXX##
+		self.scene = MyGraphicsScene( self )
+		##XXX##
+		self.scene.mousePressed.connect( self.sceneMousePress )
 		self.ui.graphicsView.setScene(self.scene)
 		self.ui.graphicsView.setSceneRect(0, 0, self.lengthX, self.lengthY)
 		self.ui.graphicsView.centerOn(0,0)
 		self.ui.graphicsView.setInteractive( True )
 		self.ui.graphicsView.setDragMode( QtGui.QGraphicsView.ScrollHandDrag )
 		
+		#параметры для маркера
+		self.itemLine = None
+		self.itemBox = None
+		self.itemText = None
+		self.x_marker = 0
+		self.y_marker = 0
+		self.maxScaleY = 0
+		self.showMarker = False
+
+		self.pen_marker = QtGui.QPen( QtGui.QColor(170,170,170) )
+		self.pen_marker.setWidth(1)
+		self.pen_marker.setStyle( QtCore.Qt.DashDotLine )
+	
+		self.font_marker = QtGui.QFont()
+		self.font_marker.setPointSize(9)
+	
+		self.bx_marker = QtGui.QPen( QtGui.QColor(110,110,110) )
+		self.bx_marker.setWidth(15)
+		self.bx_marker.setCapStyle( QtCore.Qt.RoundCap )
+		
 		#ширина линии графика (пиксель)
 		self.pxLenGraph = 0
 
-		self.showRX = True
-		self.showTX = True
-		
 		#соединение с БД
-		self.db = MyDB( myconfig.file_db )
+		self.db = db
+		self.qset = qset
 
 		#цвета графиков
 		rgbRX, rgbTX = self.db.optGetColor()
@@ -70,17 +94,41 @@ class ViewSessionExt( QtGui.QMainWindow ):
 		self.ui.lblColorRX.setStyleSheet("background-color: %s;"%(rgbRX) )
 		self.ui.lblColorTX.setStyleSheet("background-color: %s;"%(rgbTX) )
 
-
-		self.timeScale = 1 #масштабный коэф. по оси времени: во сколько раз ужимаем ось времени
-		# 1px = 1sec / timeScale
 		self.maxZoom = 8 #максимальное значение zoom
+		
+		# *** инициализация настроек *** #
+		#Отображаем ли линейку
+		self.showMarker = self.qset.isShowMarkerSession()
+
+		self.showRX = self.qset.isShowRXSession()
+		self.showTX = self.qset.isShowTXSession()
+
+		#масштабный коэф. по оси времени: во сколько раз ужимаем ось времени
+		# 1px = 1sec / timeScale
+		self.timeScale = self.qset.zoomSession()
+
+		#временные отметки
+		self.timestamp = self.qset.timestampSession()
+		
+		self.actionForm()
 
 	def actionForm(self):
-		self.ui.pBshowRX.toggled.connect( self.changeShowRX )
-		self.ui.pBshowTX.toggled.connect( self.changeShowTX )
+		self.ui.pBshowOptins.clicked.connect( self.dialogSessionOptions )
+		
 		self.ui.pBzoomIn.clicked.connect( self.zoomIn )
 		self.ui.pBzoomOut.clicked.connect( self.zoomOut )
-		self.ui.lblWait.hide()
+		if self.timeScale == 1:
+			self.ui.pBzoomIn.setEnabled( False )
+			self.ui.pBzoomOut.setEnabled( True )
+		elif self.timeScale == self.maxZoom:
+			self.ui.pBzoomIn.setEnabled( True )
+			self.ui.pBzoomOut.setEnabled( False )
+		else:
+			self.ui.pBzoomIn.setEnabled( True )
+			self.ui.pBzoomOut.setEnabled( True )
+		
+		self.ui.wWait.setWindowOpacity(0.45)
+		self.ui.wWait.hide()
 
 		self.listLBL.append( self.ui.lbl_v1 )
 		self.listLBL.append( self.ui.lbl_v2 )
@@ -91,6 +139,15 @@ class ViewSessionExt( QtGui.QMainWindow ):
 		#self.ui.graphicsView.setDragMode( QtGui.QGraphicsView.RubberBandDrag )
 		self.ui.graphicsView.setDragMode( QtGui.QGraphicsView.ScrollHandDrag )
 		#qaks = QtGui.QAbstractKineticScroller()
+		
+		self.dlgMO = QtGui.QDialog()
+		self.ui_dlgMO = ViewSessionOptions.Ui_DialogSessionOptions( )
+		self.ui_dlgMO.setupUi( self.dlgMO )
+
+		self.ui_dlgMO.cbRuler.stateChanged.connect( self.changeViewMarker )
+		self.ui_dlgMO.pbTraffRX.toggled.connect( self.changeShowRX )
+		self.ui_dlgMO.pbTraffTX.toggled.connect( self.changeShowTX )
+		self.ui_dlgMO.sbTimestamp.valueChanged.connect( self.changeTimestamp )
 
 
 	def setTimeSession(self, allSeconds, hour, min, sec):
@@ -171,9 +228,6 @@ class ViewSessionExt( QtGui.QMainWindow ):
 		self.ui.menubar.setEnabled( False )
 		self.ui.menubar.hide()
 
-	def drawLegend(self):
-		pass
-
 	def drawGrid(self, maxScaleY):
 		pen = QtGui.QPen( QtGui.QColor(170,170,170) )
 		pen.setWidth(1)
@@ -186,8 +240,9 @@ class ViewSessionExt( QtGui.QMainWindow ):
 		min = 0
 		while x < self.Lx:
 			self.scene.addLine( x+self.shiftX, 0, x+self.shiftX, self.lengthY - self.shiftY, pen )
-			x += 60  # расстояние между вертикальными линиями сетки - 60 сек
-			min += self.timeScale
+			x += 60.0*self.timestamp/self.timeScale  # расстояние между вертикальными линиями сетки - 60 сек
+			#min = (x/60.0)*self.timeScale
+			min += self.timestamp
 			#print "x=%s ---> %s"%(x,min)
 			txt = self.scene.addText( "%s"%min, font )
 			txt.setPos( self.shiftX + x -7 , self.lengthY - self.shiftY )
@@ -211,6 +266,8 @@ class ViewSessionExt( QtGui.QMainWindow ):
 			
 			currY = currY - stepLineY
 			it += 1
+
+		#self.scene.update()
 	
 	def drawSystemCoord(self):
 		pen = QtGui.QPen( QtGui.QColor(100,100,100) )
@@ -222,7 +279,8 @@ class ViewSessionExt( QtGui.QMainWindow ):
 	def drawGraph(self):
 
 		#рисуем текст "Rendering..." на графике
-		self.ui.lblWait.show()
+		#self.ui.lblWait.show()
+		self.ui.wWait.show()
 
 		self.calcTimeScale()
 
@@ -231,6 +289,12 @@ class ViewSessionExt( QtGui.QMainWindow ):
 		#подготовка графических штучек
 		penRX = QtGui.QPen( self.colorRX )
 		penTX = QtGui.QPen( self.colorTX )
+		
+		penRX.setWidth( 1 )
+		penTX.setWidth( 1 )
+		
+		brushRX = QtGui.QBrush(self.colorRX)
+		brushTX = QtGui.QBrush(self.colorTX)
 
 		#расчет графика
 		bufRX = {}
@@ -241,17 +305,23 @@ class ViewSessionExt( QtGui.QMainWindow ):
 		j = 0
 		len_buf_traff = len(self.buffSessionTraff) - 1
 		#print "len_buf_traff=%s"%(len_buf_traff)
-		#TODO: заменить это безобразие
 		while j < len_buf_traff:
 			rx1 = int( self.buffSessionTraff[j+1]["rx"] )
 			tx1 = int( self.buffSessionTraff[j+1]["tx"] )
 			qdt_delta = StatistData.diffStrTime( self.buffSessionTraff[j]["timestamp"], self.buffSessionTraff[j+1]["timestamp"] )
 			self.pxLenGraph = (1.0*qdt_delta)/self.timeScale #ширина линии графика
-			bufRX[j] = (rx1 - int( self.buffSessionTraff[j]["rx"] ))/qdt_delta #сердняя вх. скорость за промежуток времени qdt_delta
+			if qdt_delta != 0:
+				bufRX[j] = (rx1 - int( self.buffSessionTraff[j]["rx"] ))/qdt_delta #сердняя вх. скорость за промежуток времени qdt_delta
+			else:
+				bufRX[j] = 0
 			#bufRX[j] = (rx1 - int( self.buffSessionTraff[j]["rx"] )) #средняя вх. скорость
 			if bufRX[j] > maxRX:
 				maxRX = bufRX[j]
-			bufTX[j] = (tx1 - int( self.buffSessionTraff[j]["tx"] ))/qdt_delta #сердняя исх. скорость за промежуток времени qdt_delta
+
+			if qdt_delta != 0:
+				bufTX[j] = (tx1 - int( self.buffSessionTraff[j]["tx"] ))/qdt_delta #сердняя исх. скорость за промежуток времени qdt_delta
+			else:
+				bufTX[j] = 0
 			#bufTX[j] = (tx1 - int( self.buffSessionTraff[j]["tx"] )) #средняя исх. скорость
 			if bufTX[j] > maxTX:
 				maxTX = bufTX[j]
@@ -278,6 +348,7 @@ class ViewSessionExt( QtGui.QMainWindow ):
 			m += 1
 		maxScaleY = 2**m
 		#print "maxScaleY=%s"%maxScaleY
+		self.maxScaleY = maxScaleY
 
 		
 		#!#dx = self.shiftX + self.pxLenGraph/2.0
@@ -287,22 +358,27 @@ class ViewSessionExt( QtGui.QMainWindow ):
 		x=0
 		j=0
 		#XXX: очисттка экрана от надписей перед прорисовкой
-		self.scene.clear()
+		#self.scene.clear()
+		len_buf_traff = len( bufDeltaT )
 		while j < len_buf_traff:
-			penRX.setWidth( bufDeltaT[j] )
-			penTX.setWidth( bufDeltaT[j] )
+			#*#penRX.setWidth( bufDeltaT[j] )
+			#*#penTX.setWidth( bufDeltaT[j] )
 
 			if self.showRX:
 				r = (self.Ly*(1.0 / maxScaleY))*bufRX[j]
 				#print "bufRX[%s]=%s;  r=%s"%(j,bufRX[j], r)
 				if r != 0:
-					self.scene.addLine( x+dx, self.Ly, x+dx, self.Ly-r, penRX )
+					#*#self.scene.addLine( x+dx, self.Ly, x+dx, self.Ly-r, penRX )
+					rect = self.scene.addRect( x, self.Ly-r, bufDeltaT[j], r, penRX, brushRX )
+					#rect.setOpacity(0.8)
 
 			if self.showTX:
 				t = (self.Ly*(1.0 / maxScaleY))*bufTX[j]
 				#print "bufTX[%s]=%s;  t=%s"%(j,bufTX[j], t)
 				if t != 0:
-					self.scene.addLine( x+dx, self.Ly, x+dx, self.Ly-t, penTX )
+					#*#self.scene.addLine( x+dx, self.Ly, x+dx, self.Ly-t, penTX )
+					rect = self.scene.addRect( x, self.Ly-t, bufDeltaT[j], t, penTX, brushTX )
+					#rect.setOpacity(0.8)
 
 			#print "%s --> x=%s (%s), r=%s t=%s"%(j,x,self.pxLenGraph, r, t)
 			#!#x += self.pxLenGraph
@@ -327,23 +403,23 @@ class ViewSessionExt( QtGui.QMainWindow ):
 		else:
 			txt.setPos( self.allSec_t/self.timeScale, self.Ly/4 )
 
+		#рисуем маркер
+		self.drawMarkerScene()
+
 		#убираем текст "Rendering..." и отображаем график
 		self.scene.update()
 		#self.ui.graphicsView.centerOn(x,0)
-		self.ui.lblWait.hide()
+		#self.ui.lblWait.hide()
+		self.ui.wWait.hide()
 
-	def changeShowRX(self):
-		if self.showRX:
-			self.showRX = False
-		else:
-			self.showRX = True
+	def changeShowRX(self, state):
+		self.showRX = state
+		self.qset.showRXSession( state )
 		self.drawGraph()
 
-	def changeShowTX(self):
-		if self.showTX:
-			self.showTX = False
-		else:
-			self.showTX = True
+	def changeShowTX(self, state):
+		self.showTX = state
+		self.qset.showTXSession( state )
 		self.drawGraph()
 
 
@@ -354,13 +430,13 @@ class ViewSessionExt( QtGui.QMainWindow ):
 		else:
 			self.Lx = self.lengthX-self.shiftX
 		
-		deltaT_plus = 600/self.timeScale #добавили 600 - делаем сцену на 10 минут больше, для красной линии конца
-		self.Lx += 600/self.timeScale
+		deltaT_plus = 300/self.timeScale #добавили 600 - делаем сцену на 10 минут больше, для красной линии конца
+		self.Lx += 300/self.timeScale
 		
 		self.ui.graphicsView.setSceneRect(0, 0, self.Lx, self.lengthY) 
 		
 		#минимальная толщина линии графика
-		min_pxLenGraph = 1/self.timeScale
+		#min_pxLenGraph = 1/self.timeScale
 
 		#кнопочки масштаба
 		if self.timeScale == 1:
@@ -373,7 +449,7 @@ class ViewSessionExt( QtGui.QMainWindow ):
 			self.ui.pBzoomOut.setEnabled( False )
 			self.ui.pBzoomIn.setEnabled( True )
 		
-		#print "min_pxLenGraph=%s"%(min_pxLenGraph)
+		#print self.timeScale
 		#if min_pxLenGraph < 1:
 		#	self.timeScale = 1
 		#else:
@@ -386,8 +462,104 @@ class ViewSessionExt( QtGui.QMainWindow ):
 		if self.timeScale > 1:
 			self.timeScale = self.timeScale/2
 			self.drawGraph()
+			self.qset.setZoomSession( self.timeScale )
 
 	def zoomOut(self):
 		self.timeScale = self.timeScale*2
 		self.drawGraph()
+		self.qset.setZoomSession( self.timeScale )
 
+	#---------------- marker -----------------------#
+	#вызывается, когда кликают на сцену
+	def sceneMousePress(self, x, y):
+		self.x_marker = x
+		self.y_marker = y
+
+		if self.itemLine != None:
+			self.itemLine.hide()
+			self.itemLine = None
+		if self.itemBox != None:
+			self.itemBox.hide()
+			self.itemBox = None
+		if self.itemText != None:
+			self.itemText.hide()
+			self.itemText = None
+		self.drawMarkerScene()
+	
+
+	def drawMarkerScene(self):
+		x = self.x_marker
+		y = self.y_marker
+
+		if self.showMarker:
+			val = (self.maxScaleY - (1.0*y / self.Ly )*self.maxScaleY)
+			if val < 0:
+				val = 0
+			if val > 1048576:
+				val = "%.2f MB/s"%( val/1048576.0 )
+			elif val > 1024:
+				val = "%.2f kB/s"%(val/1024.0)
+			else:
+				val = "%.2f B/s"%(val)
+			self.itemLine = self.scene.addLine( 0, y, self.Lx, y, self.pen_marker )
+			dy = 10
+			if y < 20:
+				dy = -15
+			self.itemBox = self.scene.addLine( x+15, y-dy, x+80, y-dy, self.bx_marker )
+			self.itemText = self.scene.addText( "%s"%val, self.font_marker )
+			self.itemText.setPos( x+15, (y-(dy+12)) )
+		else:
+			self.itemLine = None
+			self.itemBox = None
+			self.itemText = None
+	
+	#-----------------#
+	def dialogSessionOptions(self):
+
+		#включение линейки
+		if self.qset.isShowMarkerSession():
+			self.ui_dlgMO.cbRuler.setCheckState( QtCore.Qt.Checked )
+			self.showMarker = True
+			self.qset.showMarkerSession( True )
+		else:
+			self.ui_dlgMO.cbRuler.setCheckState( QtCore.Qt.Unchecked )
+			self.showMarker = False
+			self.qset.showMarkerSession( False )
+
+		#Отображение графиков
+		if self.showRX:
+			self.ui_dlgMO.pbTraffRX.setChecked( True )
+			self.qset.showRXSession( True )
+		else:
+			self.ui_dlgMO.pbTraffRX.setChecked( False )
+			self.qset.showRXSession( False )
+		
+		if self.showTX:
+			self.ui_dlgMO.pbTraffTX.setChecked( True )
+			self.qset.showTXSession( True )
+		else:
+			self.ui_dlgMO.pbTraffTX.setChecked( False )
+			self.qset.showTXSession( False )
+
+		#Отображение значений временной метки
+		self.ui_dlgMO.sbTimestamp.setValue( self.qset.timestampSession() )
+
+		self.dlgMO.show()
+		self.dlgMO.exec_()
+
+	#изменение видимости линейки
+	def changeViewMarker(self, state ):
+		if state == QtCore.Qt.Checked:
+			self.showMarker = True
+			self.qset.showMarkerSession( True )
+		else:
+			self.showMarker = False
+			self.qset.showMarkerSession( False )
+
+	#изменения значений временных меток
+	def changeTimestamp( self, value ):
+		self.ui_dlgMO.sbTimestamp.setEnabled( False )
+		self.qset.setTimestampSession( "%s"%value )
+		self.timestamp = (int)(value)
+		self.drawGraph()
+		self.ui_dlgMO.sbTimestamp.setEnabled( True )
